==> haskell-xml-conduit-1.4.0.2-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-xml-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml-conduit
version: 1.4.0.2
id: xml-conduit-1.4.0.2-7vb4Bw2Z28qIrjuvfmrYGe
key: xml-conduit-1.4.0.2-7vb4Bw2Z28qIrjuvfmrYGe
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://github.com/snoyberg/xml
synopsis: Pure-Haskell utilities for dealing with XML with the conduit package.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/xml-conduit>.
category: XML, Conduit
author: Michael Snoyman <michael@snoyman.com>, Aristid Breitkreuz <aristidb@googlemail.com>
exposed: True
exposed-modules:
    Text.XML.Stream.Parse Text.XML.Stream.Render Text.XML.Unresolved
    Text.XML.Cursor Text.XML.Cursor.Generic Text.XML
hidden-modules: Text.XML.Stream.Token
abi: 085e6660c1d2e612404a0178e363bd69
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/xml-conduit-1.4.0.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/xml-conduit-1.4.0.2
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/xml-conduit-1.4.0.2
hs-libraries: HSxml-conduit-1.4.0.2-7vb4Bw2Z28qIrjuvfmrYGe
depends:
    attoparsec-0.13.1.0-8poMzD5ooNXJ4NDLaelDWq base-4.9.0.0
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    blaze-html-0.8.1.3-J9yr8vH3H9ALelvCpTjDjF
    blaze-markup-0.7.1.1-JmLydCOPoKfKgaFgoOctdP bytestring-0.10.8.1
    conduit-1.2.8-D9dRTYSavk8HJ0UStkfE43
    conduit-extra-1.1.15-9cN22ayihO7Dd9VUMeez1K containers-0.5.7.1
    data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr deepseq-1.4.2.0
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    resourcet-1.1.9-J17FkGhZ2yV57Ehh8hruPC
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    xml-types-0.3.6-KjWhtX04gsiBko21cGwOxT
haddock-interfaces: /usr/share/doc/haskell-xml-conduit/html/xml-conduit.haddock
haddock-html: /usr/share/doc/haskell-xml-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xml-conduit-1.4.0.4-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-xml-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml-conduit
version: 1.4.0.4
id: xml-conduit-1.4.0.4-C5gqbUtQ6Lb8x9eYy50Usu
key: xml-conduit-1.4.0.4-C5gqbUtQ6Lb8x9eYy50Usu
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://github.com/snoyberg/xml
synopsis: Pure-Haskell utilities for dealing with XML with the conduit package.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/xml-conduit>.
category: XML, Conduit
author: Michael Snoyman <michael@snoyman.com>, Aristid Breitkreuz <aristidb@googlemail.com>
exposed: True
exposed-modules:
    Text.XML.Stream.Parse Text.XML.Stream.Render Text.XML.Unresolved
    Text.XML.Cursor Text.XML.Cursor.Generic Text.XML
hidden-modules: Text.XML.Stream.Token
abi: 6d1ee83956350cf179691fc3c2067620
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/xml-conduit-1.4.0.4
library-dirs: /usr/lib/ghc-8.0.1/site-local/xml-conduit-1.4.0.4
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/xml-conduit-1.4.0.4
hs-libraries: HSxml-conduit-1.4.0.4-C5gqbUtQ6Lb8x9eYy50Usu
depends:
    attoparsec-0.13.1.0-6gEFbI8p8A3LThVdJgpVvH base-4.9.0.0
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    blaze-html-0.8.1.3-J9yr8vH3H9ALelvCpTjDjF
    blaze-markup-0.7.1.1-JmLydCOPoKfKgaFgoOctdP bytestring-0.10.8.1
    conduit-1.2.9-IqfCpUleYsf85Inkwdla2
    conduit-extra-1.1.15-9BEhw2PHvUTFj1lUJfHKAK containers-0.5.7.1
    data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr deepseq-1.4.2.0
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    xml-types-0.3.6-KjWhtX04gsiBko21cGwOxT
haddock-interfaces: /usr/share/doc/haskell-xml-conduit/html/xml-conduit.haddock
haddock-html: /usr/share/doc/haskell-xml-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
